#ifndef _EFL_CANVAS_GESTURE_RECOGNIZER_TRIPLE_TAP_EO_H_
#define _EFL_CANVAS_GESTURE_RECOGNIZER_TRIPLE_TAP_EO_H_

#ifndef _EFL_CANVAS_GESTURE_RECOGNIZER_TRIPLE_TAP_EO_CLASS_TYPE
#define _EFL_CANVAS_GESTURE_RECOGNIZER_TRIPLE_TAP_EO_CLASS_TYPE

typedef Eo Efl_Canvas_Gesture_Recognizer_Triple_Tap;

#endif

#ifndef _EFL_CANVAS_GESTURE_RECOGNIZER_TRIPLE_TAP_EO_TYPES
#define _EFL_CANVAS_GESTURE_RECOGNIZER_TRIPLE_TAP_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
/** This is the recognizer for Triple-tap gestures. See
 * @ref Efl_Canvas_Gesture_Triple_Tap and @ref Efl_Canvas_Gesture_Recognizer.
 * For internal use only.
 *
 * @ingroup Efl_Canvas_Gesture_Recognizer_Triple_Tap
 */
#define EFL_CANVAS_GESTURE_RECOGNIZER_TRIPLE_TAP_CLASS efl_canvas_gesture_recognizer_triple_tap_class_get()

EWAPI const Efl_Class *efl_canvas_gesture_recognizer_triple_tap_class_get(void) EINA_CONST;
#endif /* EFL_BETA_API_SUPPORT */

#endif
